# This file is auto-generated by hatch-gradle-version. Do not edit.

GRADLE_VERSION = "1.0.2"
FULL_VERSION = "1.0.2.1.0.0"

ARCHIVES_BASE_NAME = "hierophantics"
CARDINAL_COMPONENTS_VERSION = "5.2.1"
CLOTH_CONFIG_VERSION = "11.1.118"
FABRIC_API_VERSION = "0.92.2+1.20.1"
FABRIC_KOTLIN_VERSION = "1.10.10+kotlin.1.9.10"
HEXCASTING_VERSION = "0.11.2-pre-702"
INLINE_VERSION = "1.0.2-51"
KOTLIN_STDLIB_DEFAULT_DEPENDENCY = "false"
LOADER_VERSION = "0.16.7"
MAVEN_GROUP = "robotgiggle.hierophantics"
MINECRAFT_VERSION = "1.20.1"
MOD_VERSION = "1.0.2"
ORG_GRADLE_JVMARGS = "-Xmx1G"
ORG_GRADLE_PARALLEL = "true"
PATCHOULI_VERSION = "84"
PAUCAL_VERSION = "0.6.0-pre-118"
YARN_MAPPINGS = "1.20.1+build.10"



from importlib.resources import Package
from typing_extensions import override

from hexdoc.plugin import (
    HookReturn,
    ModPlugin,
    ModPluginImpl,
    ModPluginWithBook,
    hookimpl,
)

import hexdoc_hierophantics

from .__gradle_version__ import FULL_VERSION, GRADLE_VERSION
from .__version__ import PY_VERSION


class HierophanticsPlugin(ModPluginImpl):
    @staticmethod
    @hookimpl
    def hexdoc_mod_plugin(branch: str) -> ModPlugin:
        return HierophanticsModPlugin(branch=branch)


class HierophanticsModPlugin(ModPluginWithBook):
    @property
    @override
    def modid(self) -> str:
        return "hierophantics"

    @property
    @override
    def full_version(self) -> str:
        return FULL_VERSION

    @property
    @override
    def mod_version(self) -> str:
        return GRADLE_VERSION

    @property
    @override
    def plugin_version(self) -> str:
        return PY_VERSION

    @override
    def resource_dirs(self) -> HookReturn[Package]:
        # lazy import because generated may not exist when this file is loaded
        # eg. when generating the contents of generated
        # so we only want to import it if we actually need it
        from ._export import generated

        return generated

    @override
    def jinja_template_root(self) -> tuple[Package, str]:
        return hexdoc_hierophantics, "_templates"
